==> gc_board_0.09.00.tar.gz: gc_board_0.09.00/install/install_wizard1.php <==
<?
///////////////////////////////////////////////////////////////////////////
// install_wizard1.php
// gc_board ġ  ù ° 
// 2005. 7. 19.
///////////////////////////////////////////////////////////////////////////
?>
<html>
<head>
<title>gc_board ġ  -ù ° ܰ-</title>
<meta http-equiv="Content-Type" content="text/html; charset=euc-kr">
<link href="../include/gc_board.css" rel="stylesheet" type="text/css">
</head>

<body>
<center>
<br>
<strong><font size="4" color="#7777ff">gc_board ġ  -ù ° ܰ-</font></strong>
<br><br><br>
<?
//  gc_board ġǾ ֳ Ȯ
$gc_board_ok = false;
if (file_exists("../config/db_info.gcs"))
{
	$gc_board_ok = true;

	$info_view = file_get_contents("../config/db_info.gcs");
	$con_info = explode(" ", $info_view);

	$connect = @mysql_connect($con_info[0], $con_info[1], $con_info[2])
			or $gc_board_ok = false;
	@mysql_select_db($con_info[3])
			or $gc_board_ok = false;
}
if ($gc_board_ok)
{
?>
	<strong><font color="red">GC_BOARD ̹ ġǾ ֽϴ.<br>
	<a href="uninstall.php"></a>    ٽ ġ ּ.</font></strong><br><br>
	</center></body></html>
<?
	exit;
}
?>
  <form action="install_wizard2.php" method="post" name="db_info_form" id="db_info_form">
  <table width="600" border="0" cellspacing="5" cellpadding="1" class="main">
    <tr>
      <td bgcolor="#555555" colspan="2" height="1"></td>
    </tr>
    <tr> 
      <td>Database Server(MySQL ) <strong>ġ</strong></td>
      <td><input name="con_host" type="text" class="inputform" id="con_host" value="localhost"></td>
    </tr>
    <tr> 
      <td>Database Server(MySQL )   ϴ <strong></strong></td>
      <td><input name="con_user" type="text" class="inputform" id="con_user"></td>
    </tr>
    <tr> 
      <td>Database Server(MySQL )   ϴ <strong>н</strong></td>
      <td><input name="con_passwd" type="password" class="inputform" id="con_passwd"></td>
    </tr>
    <tr> 
      <td>gc_board ġ <strong>DB</strong></td>
      <td><input name="con_db" type="text" class="inputform" id="con_db"></td>
    </tr>
    <tr>
      <td bgcolor="#555555" colspan="2" height="1"></td>
    </tr>
    <tr align="center" bgcolor="#ffffff"> 
      <td colspan="2"><input type="submit" class="submitform" name="Submit" value="Ȯ"></td>
    </tr>
  </table>
  </form>
</body>
</html>

==> gc_board_0.09.01.tar.gz: gc_board_0.09.01/install/install_wizard1.php <==
<?
///////////////////////////////////////////////////////////////////////////
// install_wizard1.php
// gc_board ġ  ù ° 
// 2005. 8. 20.
///////////////////////////////////////////////////////////////////////////
?>
<html>
<head>
<title>gc_board ġ  -ù ° ܰ-</title>
<meta http-equiv="Content-Type" content="text/html; charset=euc-kr">
<link href="gc_board.css" rel="stylesheet" type="text/css">
</head>

<body>
<center>
<br>
<strong><font size="4" color="#7777ff">gc_board ġ  -ù ° ܰ-</font></strong>
<br><br><br>
<?
//  gc_board ġǾ ֳ Ȯ
$gc_board_ok = false;
if (file_exists("../config/db_info.gcs"))
{
	$gc_board_ok = true;

	$info_view = file_get_contents("../config/db_info.gcs");
	$con_info = explode(" ", $info_view);

	$connect = @mysql_connect($con_info[0], $con_info[1], $con_info[2])
			or $gc_board_ok = false;
	@mysql_select_db($con_info[3])
			or $gc_board_ok = false;
}
if ($gc_board_ok)
{
?>
	<strong><font color="red">gc_board ̹ ġǾ ֽϴ.<br>
	<a href="../admin/admin_index.php"></a>   ٽ ġ ּ.</font></strong><br><br>
	</center></body></html>
<?
	exit;
}
?>
  <form action="install_wizard2.php" method="post" name="db_info_form" id="db_info_form">
  <table width="600" border="0" cellspacing="5" cellpadding="1" class="main">
    <tr>
      <td bgcolor="#555555" colspan="2" height="1"></td>
    </tr>
    <tr> 
      <td>Database Server(MySQL ) <strong>ġ</strong></td>
      <td><input name="con_host" type="text" class="inputform" id="con_host" value="localhost"></td>
    </tr>
    <tr> 
      <td>Database Server(MySQL )   ϴ <strong></strong></td>
      <td><input name="con_user" type="text" class="inputform" id="con_user"></td>
    </tr>
    <tr> 
      <td>Database Server(MySQL )   ϴ <strong>н</strong></td>
      <td><input name="con_passwd" type="password" class="inputform" id="con_passwd"></td>
    </tr>
    <tr> 
      <td>gc_board ġ <strong>DB</strong></td>
      <td><input name="con_db" type="text" class="inputform" id="con_db"></td>
    </tr>
    <tr>
      <td bgcolor="#555555" colspan="2" height="1"></td>
    </tr>
    <tr align="center" bgcolor="#ffffff"> 
      <td colspan="2"><input type="submit" class="submitform" name="Submit" value="Ȯ"></td>
    </tr>
  </table>
  </form>
</body>
</html>
